@@ -372,11 +372,6 @@ dhcpcd_status_cb(DHCPCD_CONNECTION *con,
     bool refresh;
     WI_SCAN *w;
 
-#ifdef ENABLE_NLS
-    // need to rebind here for tooltip update
-    textdomain ( GETTEXT_PACKAGE );
-#endif
-
     g_message(_("Status changed to %s"), status_msg);
     if (status == DHC_DOWN) {
         msg = N_(last == DHC_UNKNOWN ?
@@ -594,7 +589,7 @@ dhcpcd_wpa_scan_cb(DHCPCD_WPA *wpa, gpointer p)
         g_critical("No interface for WPA %p", wpa);
         return;
     }
-    g_message(_("%s: Received scan results"), i->ifname);
+    //g_message(_("%s: Received scan results"), i->ifname);
     lerrno = errno;
     errno = 0;
     scans = dhcpcd_wi_scans(i);
@@ -616,7 +611,6 @@ dhcpcd_wpa_scan_cb(DHCPCD_WPA *wpa, gpointer p)
         TAILQ_INSERT_TAIL(&dhcp->wi_scans, w, next);
     } else {
 		if (!i->up) {
-			char *txt, *t;
 
 			txt = NULL;
 			msg = N_("New Access Point");
@@ -703,9 +697,6 @@ static gboolean dhcpcdui_button_press_event (GtkWidget *widget, GdkEventButton *
 {
     DHCPCDUIPlugin * dhcp = lxpanel_plugin_get_data (widget);
 
-#ifdef ENABLE_NLS
-    textdomain ( GETTEXT_PACKAGE );
-#endif
     /* Show or hide the popup menu on left-click */
     if (event->button == 1)
     {
@@ -719,9 +710,8 @@ static GtkWidget *dhcpcdui_configure (LXPanel *panel, GtkWidget *p)
 {
     DHCPCDUIPlugin * dhcp = lxpanel_plugin_get_data (p);
 
-#ifdef ENABLE_NLS
-    textdomain ( GETTEXT_PACKAGE );
-#endif
+    if (!dhcp->tray_icon) return NULL;
+
     return prefs_show (dhcp);
 }
 
@@ -731,6 +721,12 @@ static void dhcpcdui_configuration_changed (LXPanel *panel, GtkWidget *p)
     const char *icon;
     DHCPCD_WI_SCAN *s1;
 
+    if (!dhcp->active)
+    {
+        gtk_widget_hide (dhcp->plugin);
+        return;
+    }
+
     if (!dhcp->ani_timer)
     {
         s1 = get_strongest_scan (p);
@@ -744,6 +740,19 @@ static void dhcpcdui_configuration_changed (LXPanel *panel, GtkWidget *p)
     }
 }
 
+/* Handler for control message */
+static gboolean dhcpcdui_control_msg (GtkWidget *plugin, const char *cmd)
+{
+    DHCPCDUIPlugin *dhcp = lxpanel_plugin_get_data (plugin);
+
+    if (!g_strcmp0 (cmd, "menu"))
+    {
+        menu_show (dhcp);
+    }
+
+    return TRUE;
+}
+
 /* Plugin destructor. */
 static void dhcpcdui_destructor (gpointer user_data)
 {
@@ -773,79 +782,88 @@ static void dhcpcdui_destructor (gpointer user_data)
 static GtkWidget *dhcpcdui_constructor (LXPanel *panel, config_setting_t *settings)
 {
     /* Allocate and initialize plugin context */
-    DHCPCDUIPlugin * dhcp = g_new0 (DHCPCDUIPlugin, 1);
-    GtkWidget *p;
+    DHCPCDUIPlugin *dhcp = g_new0 (DHCPCDUIPlugin, 1);
     int val;
 
 #ifdef ENABLE_NLS
     setlocale (LC_ALL, "");
     bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-    textdomain (GETTEXT_PACKAGE);
 #endif
 
-    dhcp->tray_icon = gtk_image_new ();
-    lxpanel_plugin_set_taskbar_icon (panel, dhcp->tray_icon, "network-offline");
-    gtk_widget_set_tooltip_text (dhcp->tray_icon, _("Connecting to dhcpcd ..."));
-    gtk_widget_set_visible (dhcp->tray_icon, true);
-
-    dhcp->online = false;
-
-    TAILQ_INIT(&dhcp->wi_scans);
-    g_message(_("Connecting ..."));
-    dhcp->con = dhcpcd_new ();
-    if (dhcp->con ==  NULL)
-    {
-        g_critical ("libdhcpcd: %s", strerror(errno));
-        return NULL;
-    }
-    dhcpcd_set_progname (dhcp->con, "dhcpcd-gtk");
-
-    /* Allocate top level widget and set into Plugin widget pointer. */
+    /* Allocate top level widget and set into plugin widget pointer. */
     dhcp->panel = panel;
-    dhcp->plugin = p = gtk_button_new ();
-    gtk_button_set_relief (GTK_BUTTON (dhcp->plugin), GTK_RELIEF_NONE);
-    g_signal_connect (dhcp->plugin, "button-press-event", G_CALLBACK(dhcpcdui_button_press_event), NULL);
     dhcp->settings = settings;
-    lxpanel_plugin_set_data (p, dhcp, dhcpcdui_destructor);
-    gtk_widget_add_events (p, GDK_BUTTON_PRESS_MASK);
+    dhcp->plugin = gtk_button_new ();
+    lxpanel_plugin_set_data (dhcp->plugin, dhcp, dhcpcdui_destructor);
 
     /* Allocate icon as a child of top level */
-    gtk_container_add (GTK_CONTAINER(p), dhcp->tray_icon);
+    dhcp->tray_icon = gtk_image_new ();
+    gtk_container_add (GTK_CONTAINER (dhcp->plugin), dhcp->tray_icon);
+    lxpanel_plugin_set_taskbar_icon (panel, dhcp->tray_icon, "network-offline");
+    gtk_widget_set_tooltip_text (dhcp->tray_icon, _("Connecting to dhcpcd ..."));
 
-    /* Setup callbacks */
-    dhcpcd_set_status_callback (dhcp->con, dhcpcd_status_cb, dhcp);
-    dhcpcd_set_if_callback (dhcp->con, dhcpcd_if_cb, dhcp);
-    dhcpcd_wpa_set_scan_callback (dhcp->con, dhcpcd_wpa_scan_cb, dhcp);
-    dhcpcd_wpa_set_status_callback (dhcp->con, dhcpcd_wpa_status_cb, dhcp);
-    if (dhcpcd_try_open (dhcp))
-        dhcp->reopen_timer = g_timeout_add (DHCPCD_RETRYOPEN, dhcpcd_try_open, dhcp);
+    /* Set up button */
+    gtk_button_set_relief (GTK_BUTTON (dhcp->plugin), GTK_RELIEF_NONE);
 
-    if (config_setting_lookup_int (settings, "BgScan", &val))
+    if (system ("ps ax | grep dhcpcd | grep -qv grep"))
     {
-        dhcp->nomenu_scan_timer = val * 1000;
+        dhcp->active = FALSE;
+        g_message ("dhcpcdui: dhcpcd service not running; plugin hidden");
     }
-    else dhcp->nomenu_scan_timer = DHCPCD_WPA_SCAN_LONG;
-
-    if (config_setting_lookup_int (settings, "BgScanMenu", &val))
+    else
     {
-        dhcp->menu_scan_timer = val * 1000;
+        dhcp->active = TRUE;
+
+        dhcp->online = false;
+
+        dhcp->dialog = NULL;
+        dhcp->wpa_err = NULL;
+        dhcp->wpa_dialog = NULL;
+        dhcp->menu = NULL;
+
+        /* Connect to dhcpcd */
+        TAILQ_INIT (&dhcp->wi_scans);
+        g_message (_("Connecting ..."));
+        dhcp->con = dhcpcd_new ();
+        if (dhcp->con == NULL)
+        {
+            g_message ("libdhcpcd fail: %s", strerror (errno));
+            dhcp->active = FALSE;
+        }
+        else
+        {
+            dhcpcd_set_progname (dhcp->con, "dhcpcd-gtk");
+
+            /* Set up callbacks */
+            dhcpcd_set_status_callback (dhcp->con, dhcpcd_status_cb, dhcp);
+            dhcpcd_set_if_callback (dhcp->con, dhcpcd_if_cb, dhcp);
+            dhcpcd_wpa_set_scan_callback (dhcp->con, dhcpcd_wpa_scan_cb, dhcp);
+            dhcpcd_wpa_set_status_callback (dhcp->con, dhcpcd_wpa_status_cb, dhcp);
+
+            /* Set up timers */
+            if (dhcpcd_try_open (dhcp))
+                dhcp->reopen_timer = g_timeout_add (DHCPCD_RETRYOPEN, dhcpcd_try_open, dhcp);
+
+            if (config_setting_lookup_int (settings, "BgScan", &val))
+                dhcp->nomenu_scan_timer = val * 1000;
+            else
+                dhcp->nomenu_scan_timer = DHCPCD_WPA_SCAN_LONG;
+
+            if (config_setting_lookup_int (settings, "BgScanMenu", &val))
+                dhcp->menu_scan_timer = val * 1000;
+            else
+                dhcp->menu_scan_timer = DHCPCD_WPA_SCAN_SHORT;
+
+            /* Start background scanning */
+            if (dhcp->nomenu_scan_timer > 0)
+                dhcp->defscan_timer = g_timeout_add (dhcp->nomenu_scan_timer, bgscan, dhcp);
+        }
     }
-    else dhcp->menu_scan_timer = DHCPCD_WPA_SCAN_SHORT;
-
-    /* Start background scanning */
-    if (dhcp->nomenu_scan_timer > 0)
-        dhcp->defscan_timer = g_timeout_add (dhcp->nomenu_scan_timer, bgscan, dhcp);
-
-    /* Null dialog pointers so they don't get closed when they don't exist...*/
-    dhcp->dialog = NULL;
-    dhcp->wpa_err = NULL;
-    dhcp->wpa_dialog = NULL;
-    dhcp->menu = NULL;
 
     /* Show the widget, and return. */
-    gtk_widget_show_all (p);
-    return p;
+    gtk_widget_show_all (dhcp->plugin);
+    return dhcp->plugin;
 }
 
 FM_DEFINE_MODULE(lxpanel_gtk, dhcpcdui)
@@ -858,5 +876,6 @@ LXPanelPluginInit fm_module_init_lxpanel_gtk = {
     .config = dhcpcdui_configure,
     .reconfigure = dhcpcdui_configuration_changed,
     .button_press_event = dhcpcdui_button_press_event,
+    .control = dhcpcdui_control_msg,
     .gettext_package = GETTEXT_PACKAGE
 };
