@@ -56,8 +56,9 @@ static void set_country (_unused GObject *o, _unused gpointer data)
 {
     if (fork () == 0)
     {
-        char *args[] = { "", "-w", NULL };
-        execvp ("rc_gui", args);
+        setenv ("SUDO_ASKPASS", "/usr/lib/rc-gui/pwdrcg.sh", 1);
+        char *args[] = { "sudo", "-AE", "rc_gui", "-w", NULL };
+        execvp ("sudo", args);
     }
 }
 
@@ -76,31 +77,44 @@ wi_scan_find(DHCPCD_WI_SCAN *scan, GtkWidget *p)
     return NULL;
 }
 
-static void disconnect_prompt (DHCPCD_WPA *wpa, DHCPCD_WI_SCAN *scan)
+static void handle_ok (GtkButton *button, gpointer user_data)
 {
-    GtkWidget *dlg, *lbl;
-    char buffer[256];
-    int res;
+    DHCPCDUIPlugin *dhcp = (DHCPCDUIPlugin *) user_data;
+    wpa_disconnect (dhcp->disc_wpa, dhcp->disc_scan);
+    gtk_widget_destroy (dhcp->disc_dlg);
+}
 
-    sprintf (buffer, _("Do you want to disconnect from the Wi-Fi network '%s'?"), scan->ssid);
-    dlg = gtk_dialog_new_with_buttons (_("Disconnect Wi-Fi Network"), NULL, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT, GTK_STOCK_CANCEL, 0, GTK_STOCK_OK, 1, NULL);
-    lbl = gtk_label_new (buffer);
-    gtk_label_set_line_wrap (GTK_LABEL (lbl), TRUE);
-    gtk_label_set_justify (GTK_LABEL (lbl), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (lbl), 0.0, 0.0);
-    gtk_misc_set_padding (GTK_MISC (lbl), 10, 10);
-    gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), lbl , TRUE, TRUE, 0);
-    gtk_widget_show_all (dlg);
+static void handle_cancel (GtkButton *button, gpointer user_data)
+{
+    DHCPCDUIPlugin *dhcp = (DHCPCDUIPlugin *) user_data;
+    gtk_widget_destroy (dhcp->disc_dlg);
+}
 
-    // block while waiting for user response
-    res = gtk_dialog_run (GTK_DIALOG (dlg));
-    gtk_widget_destroy (dlg);
-    if (res) wpa_disconnect(wpa, scan);
+static void disconnect_prompt (DHCPCDUIPlugin *dhcp)
+{
+    GtkBuilder *builder;
+    char *buffer;
+
+    textdomain (GETTEXT_PACKAGE);
+
+    builder = gtk_builder_new_from_file (PACKAGE_DATA_DIR "/ui/lxpanel-modal.ui");
+
+    dhcp->disc_dlg = (GtkWidget *) gtk_builder_get_object (builder, "modal");
+    buffer = g_strdup_printf (_("Do you want to disconnect from the Wi-Fi network '%s'?"), dhcp->disc_scan->ssid);
+    gtk_label_set_text (GTK_LABEL (gtk_builder_get_object (builder, "modal_msg")), buffer);
+    g_signal_connect (gtk_builder_get_object (builder, "modal_ok"), "clicked", G_CALLBACK (handle_ok), dhcp);
+    g_signal_connect (gtk_builder_get_object (builder, "modal_cancel"), "clicked", G_CALLBACK (handle_cancel), dhcp);
+    gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (builder, "modal_pb")));
+    g_object_unref (builder);
+
+    gtk_widget_show (dhcp->disc_dlg);
+    g_free (buffer);
 }
 
 static void
 ssid_hook(GtkMenuItem *item, GtkWidget *p)
 {
+    DHCPCDUIPlugin *dhcp = lxpanel_plugin_get_data (p);
     DHCPCD_WI_SCAN *scan;
     WI_SCAN *wi;
 
@@ -117,7 +131,11 @@ ssid_hook(GtkMenuItem *item, GtkWidget *p)
             if (wpa)
             {
                 if (dhcpcd_wi_associated(wi->interface, scan))
-                    disconnect_prompt (wpa, scan);
+                {
+                    dhcp->disc_wpa = wpa;
+                    dhcp->disc_scan = scan;
+                    disconnect_prompt (dhcp);
+                }
                 else
                     wpa_configure(wpa, scan);
             }
@@ -175,16 +193,12 @@ get_security_icon(unsigned int flags, const char **icon)
 static void
 update_item(WI_SCAN *wi, WI_MENU *m, DHCPCD_WI_SCAN *scan, DHCPCDUIPlugin *dhcp)
 {
-    const char *icon;
-    GtkWidget *sel = gtk_image_new ();
-
     m->scan = scan;
 
     g_object_set_data(G_OBJECT(m->menu), "dhcpcd_wi_scan", scan);
 
     m->associated = is_associated(wi, scan);
-    if (m->associated) lxpanel_plugin_set_menu_icon (dhcp->panel, sel, "dialog-ok-apply");
-    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(m->menu), sel);
+    gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (m->menu), m->associated);
     gtk_label_set_text (GTK_LABEL(m->ssid), scan->ssid);
 
     //m->icon = gtk_image_new ();
@@ -218,13 +232,12 @@ create_menu(WI_SCAN *wis, DHCPCD_WI_SCAN *scan, GtkWidget *p)
 
     wim = g_malloc(sizeof(*wim));
     wim->scan = scan;
-    wim->menu = gtk_image_menu_item_new();
-    gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (wim->menu), TRUE);
+    wim->menu = gtk_check_menu_item_new ();
     box = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 4);
     gtk_container_add(GTK_CONTAINER(wim->menu), box);
 
     wim->ssid = gtk_label_new(NULL);
-    gtk_misc_set_alignment(GTK_MISC(wim->ssid), 0.0, 0.5);
+    gtk_label_set_xalign (GTK_LABEL (wim->ssid), 0.0);
     gtk_box_pack_start(GTK_BOX(box), wim->ssid, TRUE, TRUE, 0);
 
     wim->freq = gtk_image_new ();
@@ -344,12 +357,14 @@ menu_remove_if(WI_SCAN *wi, DHCPCDUIPlugin * dhcp)
     {
         /* if there are multiple interfaces and hence a top-level menu, remove the entry for the removed interface */
         GList *children = gtk_container_get_children (GTK_CONTAINER(dhcp->menu));
+        GList *head = children;
         while ((children = g_list_next(children)) != NULL)
         {
             GtkWidget *item = children->data;
             if (!strcmp (gtk_menu_item_get_label (GTK_MENU_ITEM(item)), wi->interface->ifname))
                 gtk_widget_destroy (GTK_WIDGET(item));
         }
+        g_list_free (head);
     }
     wi->ifmenu = NULL;
     while ((wim = TAILQ_FIRST(&wi->menus))) {
@@ -467,15 +482,6 @@ menu_bgscan(gpointer data)
     return TRUE;
 }
 
-static void dhcpcdui_popup_set_position(GtkMenu * menu, gint * px, gint * py, gboolean * push_in, gpointer data)
-{
-    DHCPCDUIPlugin * dhcp = (DHCPCDUIPlugin *) data;
-
-    /* Determine the coordinates. */
-    lxpanel_plugin_popup_set_position_helper(dhcp->panel, dhcp->plugin, GTK_WIDGET(menu), px, py);
-    *push_in = TRUE;
-}
-
 static int wifi_enabled (void)
 {
     FILE *fp;
@@ -521,7 +527,7 @@ void
 menu_show (DHCPCDUIPlugin *data)
 {
     WI_SCAN *w, *l;
-    GtkWidget *item, *image;
+    GtkWidget *item;
 
     //sicon = icon;
     notify_close();
@@ -536,6 +542,7 @@ menu_show (DHCPCDUIPlugin *data)
         // rfkill installed, h/w found, disabled
         data->menu = gtk_menu_new ();
         item = gtk_menu_item_new_with_label (_("Turn On Wi-Fi"));
+        gtk_menu_item_set_use_underline (GTK_MENU_ITEM (item), TRUE);
         g_signal_connect (G_OBJECT(item), "activate", G_CALLBACK (toggle_wifi), NULL);
         gtk_menu_shell_append (GTK_MENU_SHELL (data->menu), item);
     }
@@ -566,13 +573,7 @@ menu_show (DHCPCDUIPlugin *data)
     if ((l = TAILQ_LAST(&data->wi_scans, wi_scan_head)) && l != w) {
         data->menu = gtk_menu_new();
         TAILQ_FOREACH(w, &data->wi_scans, next) {
-            item = gtk_image_menu_item_new_with_label(
-                w->interface->ifname);
-            gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (item), TRUE);
-            image = gtk_image_new ();
-            lxpanel_plugin_set_menu_icon (data->panel, image, "network-wireless");
-            gtk_image_menu_item_set_image(
-                GTK_IMAGE_MENU_ITEM(item), image);
+            item = gtk_menu_item_new_with_label (w->interface->ifname);
             gtk_menu_shell_append(GTK_MENU_SHELL(data->menu), item);
             w->ifmenu = add_scans(w, data->plugin);
             gtk_menu_item_set_submenu(GTK_MENU_ITEM(item),
@@ -582,13 +583,13 @@ menu_show (DHCPCDUIPlugin *data)
         w->ifmenu = data->menu = add_scans(w, data->plugin);
     }
                 /* end original code block - retain indent for compares */
-
                 if (wifi_state == 1)
                 {
                     // rfkill installed, h/w found, enabled
                     item = gtk_separator_menu_item_new ();
                     gtk_menu_shell_prepend (GTK_MENU_SHELL (data->menu), item);
                     item = gtk_menu_item_new_with_label (_("Turn Off Wi-Fi"));
+                    gtk_menu_item_set_use_underline (GTK_MENU_ITEM (item), TRUE);
                     g_signal_connect (G_OBJECT(item), "activate", G_CALLBACK (toggle_wifi), NULL);
                     gtk_menu_shell_prepend (GTK_MENU_SHELL (data->menu), item);
                 }
@@ -608,9 +609,7 @@ menu_show (DHCPCDUIPlugin *data)
 
     if (data->menu) {
         gtk_widget_show_all(GTK_WIDGET(data->menu));
-        gtk_menu_popup(GTK_MENU(data->menu), NULL, NULL,
-            dhcpcdui_popup_set_position, data,
-            1, gtk_get_current_event_time());
+        gtk_menu_popup_at_widget (GTK_MENU(data->menu), data->plugin, GDK_GRAVITY_NORTH_WEST, GDK_GRAVITY_NORTH_WEST, NULL);
 
     if (data->menu_scan_timer > 0)
         data->bgscan_timer = g_timeout_add (data->menu_scan_timer,
