@@ -42,19 +42,30 @@ static DHCPCD_IF *iface;
 static char **ifaces;
 #endif
 
+static void clear_dlg (GtkButton *button, gpointer user_data)
+{
+    gtk_widget_destroy (GTK_WIDGET (user_data));
+}
+
 static void
 config_err_dialog(DHCPCD_CONNECTION *con, bool writing, const char *txt)
 {
+    GtkBuilder *builder;
     GtkWidget *edialog;
     char *t;
 
-    t = g_strconcat(_(writing ? _("Error saving") : _("Error reading")), " ",
+    textdomain (GETTEXT_PACKAGE);
+
+    builder = gtk_builder_new_from_file (PACKAGE_DATA_DIR "/ui/lxpanel-modal.ui");
+    edialog = (GtkWidget *) gtk_builder_get_object (builder, "modal");
+    t = g_strconcat(_("Config error"), " - ", _(writing ? _("Error saving") : _("Error reading")), " ",
         dhcpcd_cffile(con), "\n\n", txt, NULL);
-    edialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
-        GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", t);
-    gtk_window_set_title(GTK_WINDOW(edialog), _("Config error"));
-    gtk_dialog_run(GTK_DIALOG(edialog));
-    gtk_widget_destroy(edialog);
+    gtk_label_set_text (GTK_LABEL (gtk_builder_get_object (builder, "modal_msg")), t);
+    g_signal_connect (gtk_builder_get_object (builder, "modal_ok"), "clicked", G_CALLBACK (clear_dlg), edialog);
+    gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (builder, "modal_cancel")));
+    gtk_widget_hide (GTK_WIDGET (gtk_builder_get_object (builder, "modal_pb")));
+    g_object_unref (builder);
+    gtk_widget_show (edialog);
     g_free(t);
 }
 
@@ -635,18 +646,16 @@ prefs_show(DHCPCDUIPlugin *dhcp)
         _("Disable IPv6"));
     g_signal_connect(G_OBJECT(dhcp->noipv6), "toggled", G_CALLBACK(ipv6_toggle), dhcp);
     gtk_box_pack_start(GTK_BOX(vbox), dhcp->noipv6, false, false, 3);
-    table = gtk_table_new(6, 2, false);
+    table = gtk_grid_new ();
     gtk_box_pack_start(GTK_BOX(dhcp->controls), table, false, false, 0);
 
 #define attach_label(a, b, c, d, e)                       \
     do {                                      \
-        gtk_misc_set_alignment(GTK_MISC(a), 0.0, 0.5);            \
-        gtk_table_attach(GTK_TABLE(table), a, b, c, d, e,         \
-            GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 3, 3);      \
+        gtk_label_set_xalign (GTK_LABEL(a), 0.0); \
+        gtk_grid_attach(GTK_GRID(table), a, b, d, c - b, e - d);      \
     } while (0)
 #define attach_entry(a, b, c, d, e)                       \
-    gtk_table_attach(GTK_TABLE(table), a, b, c, d, e,             \
-        GTK_EXPAND | GTK_FILL | GTK_SHRINK, GTK_FILL | GTK_SHRINK, 3, 3);
+    gtk_grid_attach(GTK_GRID(table), a, b, d, c - b, e - d);
 
     w = gtk_label_new(_("IPv4 Address:"));
     dhcp->address = gtk_entry_new();
@@ -684,15 +693,14 @@ prefs_show(DHCPCDUIPlugin *dhcp)
     attach_label(w, 0, 1, 4, 5);
     attach_entry(dhcp->dns_search, 1, 2, 4, 5);
 
-    dhcp->clear = gtk_dialog_add_button (GTK_DIALOG(dhcp->dialog), GTK_STOCK_CLEAR, 1);
-    gtk_button_set_label (GTK_BUTTON(dhcp->clear), _("C_lear"));
-    gtk_button_set_image (GTK_BUTTON(dhcp->clear), gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON));
+    dhcp->clear = gtk_dialog_add_button (GTK_DIALOG(dhcp->dialog), _("C_lear"), 1);
+    gtk_button_set_image (GTK_BUTTON(dhcp->clear), gtk_image_new_from_icon_name ("gtk-clear", GTK_ICON_SIZE_BUTTON));
     gtk_widget_set_sensitive(dhcp->clear, false);
     g_signal_connect(G_OBJECT(dhcp->clear), "clicked", G_CALLBACK (on_clear), dhcp);
-    dhcp->rebind = gtk_dialog_add_button (GTK_DIALOG(dhcp->dialog), GTK_STOCK_APPLY, 1);
+    dhcp->rebind = gtk_dialog_add_button (GTK_DIALOG(dhcp->dialog), _("_Apply"), 1);
     gtk_widget_set_sensitive(dhcp->rebind, false);
     g_signal_connect(G_OBJECT(dhcp->rebind), "clicked", G_CALLBACK (on_rebind), dhcp);
-    gtk_dialog_add_button (GTK_DIALOG(dhcp->dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+    gtk_dialog_add_button (GTK_DIALOG(dhcp->dialog), _("_Close"), GTK_RESPONSE_CLOSE);
 
     blocks_on_change(dhcp->blocks, dhcp);
     show_config(NULL, dhcp);
